import React from 'react';
import purebem from 'purebem';
import { Provider } from 'react-redux';
import { mount } from 'enzyme';

import Datepicker from './Datepicker';
import DatepickerContainer from './DatepickerContainer';

import datepickerState from './redux/datepickerState';

import createStore from '../../test-utils/createStore';


const TestDatepicker = Datepicker({
    block: purebem.of('test-datepicker'),
    displayName: 'TestDatepicker'
});

const TestDatepickerContainer = DatepickerContainer({
    Component: TestDatepicker
});

const actionTypePrefix = 'TEST-DATEPICKER';
const path = 'component';
const root = 'test';

test('should read values from store', () => {
    const store = createStore({
        [root]: {
            [path]: datepickerState({
                value: +new Date(2000, 0, 1)
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDatepickerContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    const component = provider.find(TestDatepicker);
    expect(component.prop('value')).toBe(+new Date(2000, 0, 1));
});
